PyTDigest
=========

Python package for **fast** TDigest calculation.

- C implementation and thin Python wrapper
- suitable for big data, streaming and distributed settings
- developed for smooth compatibility with Pandas and numpy

Based on previous work of Ted Dunning and Andrew Werner.

- https://github.com/tdunning/t-digest
- https://github.com/ajwerner/tdigestc
